@@ -43,13 +43,13 @@ __all__ = ['Note']
 class Note:
 
 	name = 'C'
-	octave = 5
+	octave = 4
 	dynamics = { "volume" : 64 }
 
-	def __init__(self, name = 'C', octave = 5, dynamics = {}):
+	def __init__(self, name = 'C', octave = 4, dynamics = {}):
 		self.set_note(name, octave, dynamics)
 
-	def set_note(self, name = 'C', octave = 5, dynamics = {}):
+	def set_note(self, name = 'C', octave = 4, dynamics = {}):
 		"""Sets the note to name in octave with dynamics if
 		the name of the note is valid. Returns True if it 
 		succeeded, False otherwise."""
@@ -117,16 +117,24 @@ class Note:
 		"""Returns the current octave multiplied by twelve and adds
 		notes.note_to_int to it. This means a C-0 returns 0, C-1 
 		returns 12, etc. This method allows you to use int() on Notes."""
-		return self.octave * 12 + notes.note_to_int(self.name)
+		res = self.octave * 12 + notes.note_to_int(self.name[0])
+		for n in self.name[1:]:
+			if n == '#':
+				res += 1
+			elif n== 'b':
+				res -= 1
+		return res
+			
 
 	def __cmp__(self, other):
 		"""This method allows you to use the comparing operators
 		on Notes (>, <, ==, !=, >= and <=). So we can sort() Intervals, etc.
 		Examples:
-			Note("C") < Note("B") returns True
-			Note("C") < Note("B", 4) returns False"""
+			Note("C", 4) < Note("B", 4) returns False
+			Note("C", 4) > Note("B", 4) returns True"""
 		s = int(self)
 		o = int(other)
+
 		if s < o:
 			return -1
 		elif s > o:
