@@ -40,24 +40,41 @@ class Track:
 		self.bars.append(bar)
 
 
-
-	def add_note(self, note):
+	def add_notes(self, note, duration = None):
+		"""Adds a Note, note as string or NoteContainer to the 
+		last Bar. If the Bar is full, a new one will automatically
+		be created. If the Bar is not full but the note can't fit in,
+		this method will return False. True otherwise."""
 		if not(self.instrument.can_play_notes(note)):
 			# raise exception
 			return False
-		last_bar = self.bars[-1]
 
+		# 
+		if duration == None:
+			duration = 4
+
+		# Check whether the last bar is full,
+		# if so create a new bar and add the note there
+		last_bar = self.bars[-1]
 		if last_bar.is_full():
 			self.bars.append(Bar(last_bar.key, last_bar.meter))
 
-		self.bars[-1].add_note(note)
+		return self.bars[-1].place_notes(note, duration)
 		
 
 	def __add__(self, value):
-		self.add_bar(value)
+		"""Overloads the + operator for Tracks. Accepts Notes, 
+		notes as string, NoteContainers and Bars."""
+
+		if hasattr(value, "bar"):
+			return self.add_bar(value)
+		elif hasattr(value, "notes"):
+			return self.add_notes(value)
+		elif hasattr(value, "name") or type(value) == str:
+			return self.add_notes(value)
 
 	def __repr__(self):
-		return str(self.bars)
+		return str([self.instrument,str(self.bars)])
 
 	def __len__(self):
 		return len(self.bars)
